# LIF1.0
# Lightfield library, version 1.0
#
# Copy and modify this file to describe a set of images for
# generating a light field.
#
# Any line beginning with '#' is a comment.
#
# The light field is made up of "slabs".  Each slab is
# a regular array of images, taken from regular intervals 
# on a uv plane, looking at an st plane. Alternatively,
# the images can be created by a renderer known to the
# light field library.


# ==================== begin field description =====================
#
# The extended light fields allow additional parameterisation of the
# current view. Up to LF_MAXPARAMS number of additional parameters
# are allowed. A parameter is an integer value within the given range.
# The meaning can change, therefore a name is allowed to identify the
# parameter.
#
# The parameters are implicitely numbered starting with 0.
#
# PARAMETER min max default "name of parameter"

PARAMETER   0 255      1   position
PARAMETER   0 255    100   steepness



# The renderer - at the moment VOLPACK, VOLVIS, RENDERMAN and a
# DUMMY renderer are implemented.
#
# The configuration may be any string and is passed as it is to the
# renderer. In addition, a renderer is passed some or all of the
# arguments, but in a configurable order.
#
# RENDERER type "config" arg0, arg1, arg2, ...

RENDERER              VOLPACK
                      brainsmall.den
                      0	                  # position is arg0
                      1                   # and steepness arg1
                      QUALITY 2           # optionally, the quality of
                                          # the rendering can be specified

# ==================== begin slab specification ====================
#
# The first line gives the slab number (each number must be unique,
# and less than LF_MAXSLABS (currently 30).  It also lists the
# basename for the array of images.  For example, the line
# 	SLAB		0 data/head.rgb
# would tell the program to look in the data directory for files
# of the format "head.pn...p1.p0.u.v.rgb".
#
# For SAMPLE_UV 8 8, sampling of position at 0, 128, 255 and
# of steepness at 100 and 200 with constant lightning the
# following pictures accessed in this order:
#
# head.0.100.1.0.0.rgb
# head.0.100.1.0.1.rgb
# ...
# head.0.100.1.7.7.rgb
# head.0.200.1.0.0.rgb
# ...
# head.0.200.1.7.7.rgb
# head.128.100.1.0.0.rgb
# ...
# ...
# head.255.200.1.7.7.rgb
#
# If a renderer is given, these files may be created during creation
# of the light field.

SLAB		0 volume/volume.tiff

# These next four lines describe the location of the uv plane.  
# Each line describes one vertex of the quadrilateral.  The first
# four numbers of each line give the x,y,z,w coordinates of the
# corner vertex, and the last two numbers give texture coordinates,
# describing how to map u and v to the quadrilateral.  
#
# The four vertices should be coplanar.

# Note that the W coordinate is 0.0.  This places the uv plane
# at infinity, creating an orthographic projection for each 
# source (.rgb) image.
SLAB_UV
		-1000 -1000 1000 0.0   0 0
		 1000 -1000 1000 0.0   1 0
		 1000  1000 1000 0.0   1 1
		-1000  1000 1000 0.0   0 1



# These next four lines describe the location of the st plane.  
# Each line describes one vertex of the quadrilateral.  The first
# four numbers of each line give the x,y,z,w coordinates of the
# corner vertex, and the last two numbers give texture coordinates,
# describing how to map u and v to the quadrilateral.
#
# The four vertices should be coplanar.

SLAB_ST
		-0.5 -0.5 0.0 1.0   0 0 
		 0.5 -0.5 0.0 1.0   1 0 
		 0.5  0.5 0.0 1.0   1 1 
		-0.5  0.5 0.0 1.0   0 1 


# This line describes the dimensions of the light field array in
# u and v. (i.e. the size of the array of images.)

SAMPLES_UV	4 4

# This line describes the dimensions of the light field array in
# s and t. (i.e. the size of each image (in pixels)).

SAMPLES_ST	128 128

# This line describes the dimension of the light field array in
# parameter i when using equally spaced sampling between min and max.
# If only one sample is specified the default value is used. This is
# also the default for all parameters.
#
# SAMPLES_P i x

#SAMPLES_P 1 4   # use default value for steepness

# Alternatively, a parameter i can be sampled at specific values listed with
# SAMPLE_POINTS_P i x0 x1 x2 x3 ... xn. They don't have to be sorted.

#SAMPLE_POINTS_P 1  1 20 50 80  # sample position at 0, 20, 50 and 80
#SAMPLES_P 0 4

# In addition to or instead of the rectangular grid defined with
# SAMPLES_P and SAMPLE_POINTS_P, a set of arbitrary sample points
# can be defined. If parameters at the end are not specified,
# their default values will be used, but parameters at the beginning
# cannot be skipped.
#
# SAMPLE_POINT p1 p2 p3 .. pm

SAMPLE_POINT 0   0
SAMPLE_POINT 0  85
SAMPLE_POINT 0 170
SAMPLE_POINT 0 255

SAMPLE_POINT 85   0
SAMPLE_POINT 85  85
SAMPLE_POINT 85 170
SAMPLE_POINT 85 255

SAMPLE_POINT 170   0
SAMPLE_POINT 170 255

SAMPLE_POINT 255   0

# This line might describe the format of the images,
# but applications can also use whatever is appropriate,
# because the new liblight is able to add or remove the alpha
# channel.
#
# FORMAT		RGBA

# -------------------- end of slab 0 --------------------
